@@ -9,7 +9,7 @@ use crate::{
     log_d,
     networking::{NetworkClient, RequestArgs},
     statsig_metadata::StatsigMetadata,
-    OpsStatsEventObserver, StatsigErr, StatsigOptions,
+    OpsStatsEventObserver, StatsigOptions,
 };
 
 use super::ops_stats::OpsStatsEvent;
@@ -29,7 +29,8 @@ fn get_sdk_exception_endpoint() -> String {
 #[serde(rename_all = "camelCase")]
 pub struct ErrorBoundaryEvent {
     pub tag: String,
-    pub info: StatsigErr,
+    pub info: String,
+    pub exception: String,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub dedupe_key: Option<String>,
 
@@ -79,14 +80,12 @@ impl SDKErrorsObserver {
     }
 
     async fn log_exception(&self, e: ErrorBoundaryEvent) {
-        let exception_name = Value::String(e.info.name().to_string());
         let mut body_obj = serde_json::to_value(e).unwrap_or_default();
         if let Value::Object(ref mut map) = body_obj {
             map.insert(
                 "statsigOptions".to_string(),
                 Value::String(self.statsig_options_logging_copy.clone()),
             );
-            map.insert("exception".to_string(), exception_name);
         }
         let body = serde_json::to_string_pretty(&body_obj).unwrap_or_default();
 
